@@ -2,8 +2,8 @@
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """Lightweight :term:`computation` graphs for Python."""
 
-__version__ = "6.0.0"
-__release_date__ = "13 Apr 2020, 17:04"
+__version__ = "6.1.0"
+__release_date__ = "14 Apr 2020, 20:00"
 __title__ = "graphtik"
 __summary__ = __doc__.splitlines()[0]
 __license__ = "Apache-2.0"
@@ -16,7 +16,7 @@ from .config import (
     abort_run,
     debug,
     evictions_skipped,
-    execution_pool,
+    execution_pool_plugged,
     get_execution_pool,
     is_abort,
     is_debug,
@@ -39,8 +39,8 @@ from .config import (
     tasks_marshalled,
 )
 
-## SEE ALSO: `.plot.installed_plotter()`, `.plot.set_installed_plotter()` &
-#  `.plot.get_installed_plotter()` configs, not imported, unless plot is needed..
+## SEE ALSO: `.plot.active_plotter_plugged()`, `.plot.set_active_plotter()` &
+#  `.plot.get_active_plotter()` configs, not imported, unless plot is needed..
 
 from .modifiers import *  # noqa, on purpose to include any new modifiers
 from .netop import compose
