@@ -10,7 +10,7 @@ from typing import Any, Callable, Mapping
 import networkx as nx
 from boltons.setutils import IndexedSet as iset
 
-from .base import UNSET, Items, Plottable, aslist, astuple, jetsam
+from .base import UNSET, Items, PlotArgs, Plottable, aslist, astuple, jetsam
 from .config import is_debug, reset_abort
 from .modifiers import optional, sideffect
 from .network import ExecutionPlan, Network, NodePredicate, Solution, yield_ops
@@ -245,12 +245,19 @@ class NetworkOperation(Operation, Plottable):
             marshalled=marshalled,
         )
 
-    def _build_pydot(self, **kws):
-        """delegate to network"""
-        kws.setdefault("name", self.name)
-        kws.setdefault("title", self.name)
-        plotter = self.last_plan or self.net
-        return plotter._build_pydot(**kws)
+    def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
+        """Delegate to network if last-plan does not exist. """
+        from .plot import graphviz_html_string
+
+        plottable = self.last_plan or self.net
+        plot_args = plot_args.with_defaults(name=self.name)
+        plot_args = plottable.prepare_plot_args(plot_args)
+        assert plot_args.graph, plot_args
+
+        plot_args.graph.graph.setdefault("label", graphviz_html_string(self.name))
+        plot_args.graph.graph["_source"] = "netop"
+
+        return plot_args
 
     def compile(
         self, inputs=None, outputs=UNSET, predicate: NodePredicate = UNSET
@@ -407,8 +414,10 @@ def compose(
         mark all contained `operations` to be :term:`marshalled <marshalling>`
         (usefull when run in `parallel` with a :term:`process pool`).
     :param node_props:
-        added as-is into NetworkX graph, to provide for filtering
+        Added as-is into NetworkX graph, to provide for filtering
         by :meth:`.NetworkOperation.withset()`.
+        Also plot-rendering affected if they match `Graphviz` properties,
+        unless they start with underscore(``_``)
 
     :return:
         Returns a special type of operation class, which represents an
