@@ -1,7 +1,7 @@
 # Copyright 2016, Yahoo Inc.
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """
-Plotting of graphtik graphs (see also plot-classes on :mod:`.base` module).
+Plotting of graph graphs handled by :term:`active plotter`.
 
 Separate from `graphtik.base` to avoid too many imports too early.
 from contextlib import contextmanager
@@ -241,11 +241,6 @@ def _pub_props(*d, **kw) -> None:
     return {k: v for k, v in dict(*d, *kw).items() if not str(k).startswith("_")}
 
 
-def _render_template(tpl: jinja2.Template, **kw) -> str:
-    """Ignore falsy values, to skip attributes in template all together. """
-    return tpl.render(**{k: v for k, v in kw.items() if v})
-
-
 class NodeArgs(NamedTuple):
     """All the args for :meth:`.Plotter._make_node()` call. """
 
@@ -295,7 +290,7 @@ def _drop_gt_lt(x):
 
 
 def _escape_or_none(context: jinja2.environment.EvalContext, x, escaper):
-    """Do not markup Nones/empties, not to break `xmlattr` filter."""
+    """Do not markup Nones/empties, so `xmlattr` filter does not include them."""
     return x and jinja2.Markup(escaper(str(x)))
 
 
@@ -314,13 +309,18 @@ _jinja2_env.filters["slug"] = jinja2.evalcontextfilter(
 _jinja2_env.filters["hrefer"] = _drop_gt_lt
 
 
+def _render_template(tpl: jinja2.Template, **kw) -> str:
+    """Ignore falsy values, to skip attributes in template all together. """
+    return tpl.render(**{k: v for k, v in kw.items() if v})
+
+
 class Style:
     """
     The poor man's css-like :term:`plot styles` applied like a theme.
 
     .. NOTE::
         Changing class attributes AFTER the module has loaded WON'T change themes;
-        Either patch directly the :attr:`Plotter.style` of :term:`installed plotter`),
+        Either patch directly the :attr:`Plotter.style` of :term:`active plotter`),
         or pass a new styles to a new plotter, as described in :ref:`plot-customizations`.
 
     """
@@ -407,46 +407,46 @@ class Style:
         textwrap.dedent(
             """\
             <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-                {{- {
-                        'BORDER': penwidth | ee,
-                        'COLOR': color | ee,
-                        'BGCOLOR': fillcolor | ee
-                    } | xmlattr }}
-                ><TR><TD BORDER="1" SIDES="b"
-                {{- {
-                        'TOOLTIP': op_tooltip | truncate | eee,
-                        'HREF': op_url | hrefer | ee,
-                        'TARGET': op_link_target | ee
-                    } | xmlattr }}
+              {{- {
+              'BORDER': penwidth | ee,
+              'COLOR': color | ee,
+              'BGCOLOR': fillcolor | ee
+              } | xmlattr -}}>
+                <TR>
+                    <TD BORDER="1" SIDES="b" ALIGN="left"
+                      {{- {
+                      'TOOLTIP': op_tooltip | truncate | eee,
+                      'HREF': op_url | hrefer | ee,
+                      'TARGET': op_link_target | e
+                      } | xmlattr }}
                     >
-                    {%- if fontcolor -%}
-                        <FONT COLOR="{{ fontcolor }}">
-                    {%- endif -%}
-                    {{ '<B>OP:</B> <I>%s</I>' % op_name |ee if op_name }}
-                    {%- if fontcolor -%}
-                        </FONT>
-                    {%- endif -%}
-                    </TD></TR
-                >
+                        {%- if fontcolor -%}<FONT COLOR="{{ fontcolor }}">{%- endif -%}
+                        {{- '<B>OP:</B> <I>%s</I>' % op_name |ee if op_name -}}
+                        {%- if fontcolor -%}</FONT>{%- endif -%}
+                    </TD>
+                </TR>
                 {%- if fn_name -%}
-                <TR><TD {{- {
-                            'TOOLTIP': fn_tooltip | truncate | eee,
-                            'HREF': fn_url | hrefer | ee,
-                            'TARGET': fn_link_target | ee
-                        } | xmlattr }}
-                    >
-                    {%- if fontcolor -%}
+                <TR>
+                    <TD ALIGN="left"
+                      {{- {
+                      'TOOLTIP': fn_tooltip | truncate | eee,
+                      'HREF': fn_url | hrefer | ee,
+                      'TARGET': fn_link_target | e
+                      } | xmlattr }}
+                      >
+                        {%- if fontcolor -%}
                         <FONT COLOR="{{ fontcolor }}">
-                    {%- endif -%}
-                    <B>FN:</B> {{ fn_name | eee }}
-                    {%- if fontcolor -%}
+                        {%- endif -%}
+                        <B>FN:</B> {{ fn_name | eee }}
+                        {%- if fontcolor -%}
                         </FONT>
-                    {%- endif -%}
-                    </TD></TR>
+                        {%- endif -%}
+                    </TD>
+                </TR>
                 {%- endif %}
             </TABLE>>
             """
-        ).strip(),
+        ).strip()
     )
 
     ##########
@@ -472,13 +472,26 @@ class Style:
         "target": "_top",
     }
 
-    def __init__(self, **kw):
+    def __init__(self, _prototype: "Style" = None, **kw):
         """
         Deep-copy class-attributes (to avoid sideffects) and apply user-overrides,
 
         retargeting any :class:`Ref` on my self (from class's 'values).
+
+        :param _prototype:
+            If given, class-attributes are ignored, deep-copying "public" properties
+            only from this instance (and apply on top any `kw`).
         """
-        values = _pub_props(vars(type(self)))
+        if _prototype is None:
+            _prototype = type(self)
+        else:
+            assert isinstance(_prototype, Style), _prototype
+
+        values = {
+            k: v
+            for k, v in vars(type(self)).items()
+            if not callable(v) and not k.startswith("_")
+        }
         values.update(kw)
         self.resolve_refs(values)
 
@@ -487,7 +500,7 @@ class Style:
         Rebase any refs in styles, and deep copy (for free) as instance attributes.
 
         :raises:
-            Nothing(!), not to CRASH :term:`default installed plotter` on import-time.
+            Nothing(!), not to CRASH :term:`default active plotter` on import-time.
             Ref-errors are log-ERROR reported, and the item with the ref is skipped.
         """
 
@@ -511,6 +524,10 @@ class Style:
             values = vars(self)
         vars(self).update(remap(values, remap_item))
 
+    def with_set(self, **kw) -> "Style":
+        """Returns a deep-clone modified by `kw`."""
+        return type(self)(_prototype=self, **kw)
+
 
 class Plotter:
     """
@@ -522,14 +539,16 @@ class Plotter:
         controlling theming values & dictionaries for plots.
     """
 
-    def __init__(self, style=None):
-        self.style = style or Style()
+    def __init__(self, style: Style = None):
+        self.style: Style = style or Style()
 
-    def copy(self) -> "Plotter":
-        """deep copy of all styles"""
-        clone = type(self)(self.style)
-        clone.__dict__ = remap(vars(self), lambda *a: True)
-        return clone
+    def with_styles(self, **kw) -> "Plotter":
+        """
+        Returns a cloned plotter with deep-coped styles modified as given.
+
+        See also :meth:`Style.with_set()`.
+        """
+        return type(self)(self.style.with_set(**kw))
 
     def plot(self, plot_args: PlotArgs):
         dot = self.build_pydot(plot_args)
@@ -1011,11 +1030,11 @@ def legend(
     Generate a legend for all plots (see :meth:`.Plottable.plot()` for args)
 
     :param plotter:
-        override the :term:`installed plotter`
+        override the :term:`active plotter`
 
     See :meth:`Plotter.render_pydot` for the rest arguments.
     """
-    plotter = plotter or get_installed_plotter()
+    plotter = plotter or get_active_plotter()
     return plotter.legend(filename, show, jupyter_render)
 
 
@@ -1024,24 +1043,24 @@ def supported_plot_formats() -> List[str]:
     return [".%s" % f for f in pydot.Dot().formats]
 
 
-_installed_plotter: ContextVar[Plotter] = ContextVar(
-    "installed_plotter", default=Plotter()
-)
+_active_plotter: ContextVar[Plotter] = ContextVar("active_plotter", default=Plotter())
 
 
 @contextmanager
-def installed_plotter(plotter: Plotter) -> None:
-    """Like :func:`set_installed_plotter()` as a context-manager to reset old value. """
+def active_plotter_plugged(plotter: Plotter) -> None:
+    """
+    Like :func:`set_active_plotter()` as a context-manager, resetting back to old value.
+    """
     if not isinstance(plotter, Plotter):
         raise ValueError(f"Cannot install invalid plotter: {plotter}")
-    resetter = _installed_plotter.set(plotter)
+    resetter = _active_plotter.set(plotter)
     try:
         yield
     finally:
-        _installed_plotter.reset(resetter)
+        _active_plotter.reset(resetter)
 
 
-def set_installed_plotter(plotter: Plotter):
+def set_active_plotter(plotter: Plotter):
     """
     The default instance to render :term:`plottable`\\s,
 
@@ -1052,13 +1071,13 @@ def set_installed_plotter(plotter: Plotter):
     """
     if not isinstance(plotter, Plotter):
         raise ValueError(f"Cannot install invalid plotter: {plotter}")
-    return _installed_plotter.set(plotter)
+    return _active_plotter.set(plotter)
 
 
-def get_installed_plotter() -> Plotter:
-    """Get the previously installed  :class:`.Plotter` instance or default one."""
-    plotter = _installed_plotter.get()
+def get_active_plotter() -> Plotter:
+    """Get the previously active  :class:`.plotter` instance or default one."""
+    plotter = _active_plotter.get()
     if not isinstance(plotter, Plotter):
-        raise ValueError(f"Missing or invalid installed plotter: {plotter}")
+        raise ValueError(f"Missing or invalid active plotter: {plotter}")
 
     return plotter
