@@ -2,8 +2,13 @@
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """Extends Sphinx with :rst:dir:`graphtik` directive rendering plots from doctest code."""
 import collections.abc as cabc
+import itertools as itt
+import os
 import re
-from typing import List, Union, cast
+from collections import defaultdict
+from pathlib import Path
+from shutil import copyfileobj
+from typing import Dict, List, Set, Union, cast
 
 import sphinx
 from docutils import nodes
@@ -13,15 +18,23 @@ from sphinx.application import Sphinx
 from sphinx.config import Config
 from sphinx.domains import Domain, Index, ObjType
 from sphinx.domains.std import StandardDomain
+from sphinx.environment import BuildEnvironment
 from sphinx.ext import doctest as extdoctest
 from sphinx.locale import _, __
 from sphinx.roles import XRefRole
 from sphinx.util import logging
+from sphinx.util.console import bold  # pylint: disable=no-name-in-module
 from sphinx.writers.html import HTMLTranslator
 from sphinx.writers.latex import LaTeXTranslator
 
 from .. import __version__
 
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    # Use backported to PY<3.7 `importlib_resources` lib.
+    import importlib_resources as pkg_resources
+
 obj_name = "graphtik diagram"
 role_name = "graphtik"
 log = logging.getLogger(__name__)
@@ -58,7 +71,14 @@ def _zoomable_activation_js_code(default_zoom_opts: str) -> str:
                                 default_opts);
             svg_el.addEventListener("load", function() {{
                 // Still fails for Chrome localy :-()
-                svgPanZoom(svg_el, zoom_opts);
+                var panZoom = svgPanZoom(svg_el, zoom_opts);
+
+                // Container follows window size.
+                $(window).resize(function(){{
+                    panZoom.resize();
+                    panZoom.fit();
+                    panZoom.center();
+                }});
             }});
         }};
     }});
@@ -209,7 +229,7 @@ class _GraphtikTestDirective(extdoctest.TestDirective):
             figure
                 target:         if :name: present
                 dynaimage:      rendered as <img> or <object>
-                caption:        if :caption: present
+                caption:        if :caption: or :name: present
 
     """
 
@@ -277,23 +297,20 @@ class _GraphtikTestDirective(extdoctest.TestDirective):
             image["data-svg-zoom-opts"] = zoomable_options
         figure += image
 
-        ## See sphinx.ext.graphviz:figure_wrapper(),
-        #  and <sphinx.git>/tests/roots/test-add_enumerable_node/enumerable_node.py:MyFigure
-        #
+        # A caption is needed if :name: is given, to create a permalink on it
+        # (see sphinx/writers/html:HTMLTranslator.depart_caption()),
+        # so get it here, not to overwrite it with :name: (if given below).`
         caption = options.get("caption")
-        if caption:
-            inodes, messages = self.state.inline_text(caption, self.lineno)
-            caption_node = nodes.caption(caption, "", *inodes)
-            self.set_source_info(caption_node)
-            caption_node += messages
-            node += caption_node
 
         ## Prepare target,
         #
         if "name" in options:
             ##  adapted from: self.add_name()
             #
-            name = nodes.fully_normalize_name(options.pop("name"))
+            name = options.pop("name")
+            if not caption:
+                caption = _("plottable: ``%s``") % name
+            name = nodes.fully_normalize_name(name)
             targetname = f"graphtik-{name}"
             figure["names"].append(targetname)
             self.state.document.note_explicit_target(figure, figure)
@@ -302,6 +319,16 @@ class _GraphtikTestDirective(extdoctest.TestDirective):
             std = cast(StandardDomain, self.env.get_domain("std"))
             std.add_object("graphtik", name, self.env.docname, targetname)
 
+        ## See sphinx.ext.graphviz:figure_wrapper(),
+        #  and <sphinx.git>/tests/roots/test-add_enumerable_node/enumerable_node.py:MyFigure
+        #
+        if caption:
+            inodes, messages = self.state.inline_text(caption, self.lineno)
+            caption_node = nodes.caption(caption, "", *inodes)
+            self.set_source_info(caption_node)
+            caption_node += messages
+            figure += caption_node
+
         return [node]
 
     def _decide_img_format(self, options):
@@ -349,8 +376,9 @@ def _should_work(app: Sphinx):
     return any(re.search(regex, builder_name) for regex in builder_name_regexes)
 
 
-def _run_doctests_on_graphtik_document(app: Sphinx, doctree: nodes.Node, docname: str):
+def _run_doctests_on_graphtik_document(app: Sphinx, doctree: nodes.Node):
     """Callback of `doctree-resolved`` event. """
+    docname = app.env.docname
     from ._graphtikbuilder import get_graphtik_builder
 
     if _should_work(app) and any(doctree.traverse(graphtik_node)):
@@ -359,6 +387,90 @@ def _run_doctests_on_graphtik_document(app: Sphinx, doctree: nodes.Node, docname
         graphtik_builder.test_doc(docname, doctree)
 
 
+class DocFilesPurgatory:
+    """Keeps 2-way associations of docs <--> abs-files, to purge them."""
+
+    #: Multi-map: docnames -> abs-file-paths
+    doc_fpaths: Dict[str, Set[Path]]
+
+    def __init__(self):
+        self.doc_fpaths = defaultdict(set)
+
+    def register_doc_fpath(self, docname: str, fpath: Path):
+        """Must be absolute, for purging to work."""
+        self.doc_fpaths[docname].add(fpath)
+
+    def purge_doc(self, docname: str):
+        """Remove doc-files not used by any other doc."""
+        doc_fpaths = self.doc_fpaths
+
+        for fpath in doc_fpaths.get(docname, ()):
+            docs_involved = set(
+                docs for docs, fpaths in doc_fpaths.items() if fpath in fpaths
+            )
+            assert docname in docs_involved, (docname, docs_involved)
+
+            ## Delete file when given `docname` is the only document using it.
+            #
+            if len(docs_involved) == 1:  # equality checked also by assertion
+
+                try:
+                    log.debug(
+                        "Deleting outdated image '%s' of doc %r...", docname, fpath
+                    )
+                    fpath.unlink(missing_ok=True)
+                except Exception as ex:
+                    log.warning(
+                        "Ignoring error while deleting outdated fpath '%s': %s",
+                        fpath,
+                        ex,
+                    )
+
+        doc_fpaths.pop(docname, None)
+
+    def __getstate__(self) -> Dict:
+        """Obtains serializable data for pickling."""
+        return self.doc_fpaths
+
+    def __setstate__(self, state: Dict) -> None:
+        """Restore serialized data for pickling."""
+        self.doc_fpaths = state
+
+
+def _purge_old_document_images(app: Sphinx, env: BuildEnvironment, docname: str):
+    img_registry: DocFilesPurgatory = getattr(env, "graphtik_image_purgatory", None)
+    if img_registry:
+        try:
+            env.graphtik_image_purgatory.purge_doc(docname)
+        except Exception as ex:
+            app.logger.error(
+                bold(__("Failed purging old images due to: %s")), ex, exc_info=ex
+            )
+
+    else:
+        env.graphtik_image_purgatory = DocFilesPurgatory()
+
+
+def _stage_my_pkg_resource(inp_fname, out_fpath):
+    with pkg_resources.open_binary(__package__, inp_fname) as inp, open(
+        out_fpath, "wb"
+    ) as out:
+        copyfileobj(inp, out)
+
+
+_css_fname = "graphtik.css"
+
+
+def _copy_graphtik_static_assets(app: Sphinx, exc: Exception) -> None:
+    """Callback of `build-finished`` event. """
+    if not exc and _should_work(app):
+        dst = Path(app.outdir, "_static", _css_fname)
+        ## Builder `latex` does not have _static folder.
+        #
+        if not dst.exists() and dst.parent.exists():
+            _stage_my_pkg_resource(_css_fname, dst)
+
+
 def _validate_and_apply_configs(app: Sphinx, config: Config):
     """Callback of `config-inited`` event. """
     config.graphtik_default_graph_format is None or _valid_format_option(
@@ -367,6 +479,7 @@ def _validate_and_apply_configs(app: Sphinx, config: Config):
 
 
 def setup(app: Sphinx):
+    setup.app = app
     app.require_sphinx("2.0")
     app.setup_extension("sphinx.ext.doctest")
 
@@ -377,14 +490,13 @@ def setup(app: Sphinx):
         [cabc.Mapping],
     )
     app.add_config_value("graphtik_default_graph_format", None, "html", [str, None])
-    # TODO: impl sphinx-config --> graphtik-configs
-    app.add_config_value("graphtik_configurations", {}, "html", [cabc.Mapping])
-    # TODO: impl sphinx-config --> plot keywords
     app.add_config_value("graphtik_plot_keywords", {}, "html", [cabc.Mapping])
     app.add_config_value("graphtik_zoomable", True, "html", [bool])
+    app.add_config_value("graphtik_warning_is_error", False, "html", [bool])
+    app.add_config_value("graphtik_save_dot_files", False, "html", [bool])
     app.add_config_value(
         "graphtik_zoomable_options",
-        "{controlIconsEnabled: true, zoomScaleSensitivity: 0.4, fit: true}",
+        "{controlIconsEnabled: true, fit: true}",
         "html",
         [str],
     )
@@ -420,7 +532,11 @@ def setup(app: Sphinx):
         object_types[dir_name] = obj_type
 
     app.connect("config-inited", _validate_and_apply_configs)
-    app.connect("doctree-resolved", _run_doctests_on_graphtik_document)
+    app.connect("doctree-read", _run_doctests_on_graphtik_document)
+    app.connect("env-purge-doc", _purge_old_document_images)
+    app.connect("build-finished", _copy_graphtik_static_assets)
+
+    app.add_css_file(_css_fname)
 
     # Permanently set this, or else, e.g. +SKIP will not work!
     app.config.trim_doctest_flags = False
