@@ -13,7 +13,12 @@ import pytest
 from graphtik import base, compose, network, operation, plot
 from graphtik.modifiers import optional
 from graphtik.netop import NetworkOperation
-from graphtik.plot import Plotter, Style, get_installed_plotter, installed_plotter
+from graphtik.plot import (
+    Plotter,
+    Style,
+    get_active_plotter,
+    active_plotter_plugged,
+)
 
 
 @pytest.fixture
@@ -83,11 +88,14 @@ def test_op_label_template_full():
     got = plot._render_template(plot.Style.op_template, **kw)
     print(got)
     exp = """
-        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded" BORDER="44" COLOR="red" BGCOLOR="wheat"
-            ><TR><TD BORDER="1" SIDES="b" TOOLTIP="&lt;op &quot; &#9; tooltip&gt;" HREF="http://op_url.com_label_" TARGET="_self"
-                ><FONT COLOR="blue"><B>OP:</B> <I>the op</I></FONT></TD></TR
-            ><TR><TD TOOLTIP="&lt;fn&#10;tooltip&gt;" HREF="http://fn_url.com/quoto_and" TARGET="_top"
-                ><FONT COLOR="blue"><B>FN:</B> the fn</FONT></TD></TR>
+        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded" BORDER="44" COLOR="red" BGCOLOR="wheat">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="&lt;op &quot; &#9; tooltip&gt;" HREF="http://op_url.com_label_" TARGET="_self"
+                ><FONT COLOR="blue"><B>OP:</B> <I>the op</I></FONT></TD>
+            </TR><TR>
+                <TD ALIGN="left" TOOLTIP="&lt;fn&#10;tooltip&gt;" HREF="http://fn_url.com/quoto_and" TARGET="_top"
+                ><FONT COLOR="blue"><B>FN:</B> the fn</FONT></TD>
+            </TR>
         </TABLE>>
         """
 
@@ -102,10 +110,11 @@ def test_op_label_template_empty():
     got = plot._render_template(plot.Style.op_template)
     print(got)
     exp = """
-        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b"
-                ></TD></TR
-            >
+        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TARGET=""
+                ></TD>
+            </TR>
         </TABLE>>
         """
     assert _striplines(got) == _striplines(exp)
@@ -115,11 +124,14 @@ def test_op_label_template_fn_empty():
     got = plot._render_template(plot.Style.op_template, op_name="op", fn_name="fn")
     print(got)
     exp = """
-        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b"
-                ><B>OP:</B> <I>op</I></TD></TR
-            ><TR><TD
-                ><B>FN:</B> fn</TD></TR>
+        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TARGET=""
+                ><B>OP:</B> <I>op</I></TD>
+            </TR><TR>
+                <TD ALIGN="left" TARGET=""
+                ><B>FN:</B> fn</TD>
+            </TR>
         </TABLE>>
         """
     assert _striplines(got) == _striplines(exp)
@@ -142,10 +154,11 @@ def test_op_label_template_nones():
     got = plot._render_template(plot.Style.op_template, **kw)
     print(got)
     exp = """
-        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b"
-                ></TD></TR
-            >
+        <<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TARGET=""
+                ></TD>
+            </TR>
         </TABLE>>
         """
 
@@ -336,9 +349,9 @@ def test_plotter_customizations(pipeline, monkeypatch):
     dot = str(pipeline.plot())
     assert url in dot
 
-    ## New installed_plotter
+    ## New active_plotter
     #
-    with installed_plotter(Plotter(style=Style(kw_legend={"URL": None}))):
+    with active_plotter_plugged(Plotter(style=Style(kw_legend={"URL": None}))):
         dot = str(pipeline.plot())
         assert url not in dot
 
@@ -352,7 +365,7 @@ def test_plotter_customizations(pipeline, monkeypatch):
     assert url in dot
 
     url2 = "http://example.2.org"
-    with installed_plotter(Plotter(style=Style(kw_legend={"URL": url2}))):
+    with active_plotter_plugged(Plotter(style=Style(kw_legend={"URL": url2}))):
         dot = str(pipeline.plot())
         assert url2 in dot
         assert url not in dot
@@ -419,18 +432,24 @@ def test_node_dot_str0(dot_str_pipeline):
         splines=ortho;
         <edge> [shape=rect];
         <digraph&#58; strict> [shape=rect];
-        <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)"
-                ><B>OP:</B> <I>node</I></TD></TR
-            ><TR><TD TOOLTIP="&lt;built-in function add&gt;"
-                ><B>FN:</B> _operator.add</TD></TR>
+        <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)" TARGET=""
+                ><B>OP:</B> <I>node</I></TD>
+            </TR><TR>
+                <TD ALIGN="left" TOOLTIP="&lt;built-in function add&gt;" TARGET=""
+                ><B>FN:</B> _operator.add</TD>
+            </TR>
         </TABLE>>, shape=plain, tooltip=<node>];
         <&lt;graph&gt;> [shape=rect];
-        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)"
-                ><B>OP:</B> <I>cu:sto:m</I></TD></TR
-            ><TR><TD TOOLTIP="def func():&#10;    pass"
-                ><B>FN:</B> test.test_plot.func</TD></TR>
+        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)" TARGET=""
+                ><B>OP:</B> <I>cu:sto:m</I></TD>
+            </TR><TR>
+                <TD ALIGN="left" TOOLTIP="def func():&#10;    pass" TARGET=""
+                ><B>FN:</B> test.test_plot.func</TD>
+            </TR>
         </TABLE>>, shape=plain, tooltip=<cu:sto:m>];
         <edge> -> <node>;
         <edge> -> <cu&#58;sto&#58;m>;
@@ -446,10 +465,10 @@ def test_node_dot_str0(dot_str_pipeline):
 
 
 def test_node_dot_str1(dot_str_pipeline, monkeypatch):
-    style = get_installed_plotter().style
+    style = get_active_plotter().style
     monkeypatch.setattr(style, "py_item_url_format", "abc#%s")
-    monkeypatch.setattr(style, "op_link_target", {"target": "_self"})
-    monkeypatch.setattr(style, "fn_link_target", {"target": "bad"})
+    monkeypatch.setattr(style, "op_link_target", "_self")
+    monkeypatch.setattr(style, "fn_link_target", "bad")
 
     dot_str = str(dot_str_pipeline.plot())
     print(dot_str)
@@ -460,18 +479,24 @@ def test_node_dot_str1(dot_str_pipeline, monkeypatch):
         splines=ortho;
         <edge> [shape=rect];
         <digraph&#58; strict> [shape=rect];
-        <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="{&#x27;target&#x27;: &#x27;bad&#x27;}"
-                ><B>OP:</B> <I>node</I></TD></TR
-            ><TR><TD TOOLTIP="&lt;built-in function add&gt;" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="{&#x27;target&#x27;: &#x27;bad&#x27;}"
-                ><B>FN:</B> _operator.add</TD></TR>
+        <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="bad"
+                ><B>OP:</B> <I>node</I></TD>
+            </TR><TR>
+                <TD ALIGN="left" TOOLTIP="&lt;built-in function add&gt;" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="bad"
+                ><B>FN:</B> _operator.add</TD>
+            </TR>
         </TABLE>>, shape=plain, tooltip=<node>];
         <&lt;graph&gt;> [shape=rect];
-        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded"
-            ><TR><TD BORDER="1" SIDES="b" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="{&#x27;target&#x27;: &#x27;bad&#x27;}"
-                ><B>OP:</B> <I>cu:sto:m</I></TD></TR
-            ><TR><TD TOOLTIP="def func():&#10;    pass" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="{&#x27;target&#x27;: &#x27;bad&#x27;}"
-                ><B>FN:</B> test.test_plot.func</TD></TR>
+        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+            <TR>
+                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="bad"
+                ><B>OP:</B> <I>cu:sto:m</I></TD>
+            </TR><TR>
+                <TD ALIGN="left" TOOLTIP="def func():&#10;    pass" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="bad"
+                ><B>FN:</B> test.test_plot.func</TD>
+            </TR>
         </TABLE>>, shape=plain, tooltip=<cu:sto:m>];
         <edge> -> <node>;
         <edge> -> <cu&#58;sto&#58;m>;
